Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(765)

Unified Diff: pkg/analyzer/lib/src/generated/error.dart

Issue 1517723002: Server custom error severity support (#24452). (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: lib_renames Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/lib/source/error_processor.dart ('k') | pkg/analyzer/lib/src/task/dart.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/error.dart
diff --git a/pkg/analyzer/lib/src/generated/error.dart b/pkg/analyzer/lib/src/generated/error.dart
index 5ea9c4cfb1df131b860bd145336519e98e99e4dd..621b72d33fe872cfac742a41adc962c9a6a80c9f 100644
--- a/pkg/analyzer/lib/src/generated/error.dart
+++ b/pkg/analyzer/lib/src/generated/error.dart
@@ -6,6 +6,7 @@ library analyzer.src.generated.error;
import 'dart:collection';
+import 'package:analyzer/source/error_processor.dart';
import 'package:analyzer/src/generated/ast.dart' show AstNode;
import 'package:analyzer/src/generated/element.dart';
import 'package:analyzer/src/generated/java_core.dart';
@@ -18,18 +19,11 @@ import 'package:analyzer/task/model.dart';
import 'package:source_span/source_span.dart';
/**
* The descriptor used to associate error filters with analysis contexts in
* configuration data.
*/
-final ListResultDescriptor<List<ErrorFilter>> CONFIGURED_ERROR_FILTERS =
- new ListResultDescriptorImpl('configured.errors', const <ErrorFilter>[]);
-
-/**
- * A predicate used to potentially filter an [error].
- *
- * Returns `true` if this error should be filtered from analysis results.
- */
-typedef bool ErrorFilter(AnalysisError error);
+final ListResultDescriptor<List<ErrorProcessor>> CONFIGURED_ERROR_PROCESSORS =
+ new ListResultDescriptorImpl('configured.errors', const <ErrorProcessor>[]);
/**
* An error discovered during the analysis of some Dart code.
« no previous file with comments | « pkg/analyzer/lib/source/error_processor.dart ('k') | pkg/analyzer/lib/src/task/dart.dart » ('j') | no next file with comments »
@@ -18,18 +19,11 @@ import 'package:analyzer/task/model.dart';
import 'package:source_span/source_span.dart';
/**
- * The descriptor used to associate error filters with analysis contexts in
+ * The descriptor used to associate error processors with analysis contexts in
* configuration data.
*/

Powered by Google App Engine
This is Rietveld 408576698